Module: Asana::Resources::EventSubscription
Overview
Mixin to enable a resource with the ability to fetch events about itself.
Instance Method Summary collapse
-
#events(wait: 1, options: {}) ⇒ Object
Returns an infinite collection of events on the resource.
Instance Method Details
#events(wait: 1, options: {}) ⇒ Object
Returns an infinite collection of events on the resource.
11 12 13 |
# File 'lib/asana/resource_includes/event_subscription.rb', line 11 def events(wait: 1, options: {}) Events.new(resource: gid, client: client, wait: wait, options: ) end |